@@ -5,7 +5,7 @@ function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in ob
 import React, { PropTypes, Component } from 'react';
 import FormTextInput from './form-text-input';
 
-var EREG_NUMBER = /^[0-9]*$/;
+//TODO Check if min and max are not defined
 
 export default function FormNumberInput(_ref) {
   var onChange = _ref.onChange,
@@ -13,8 +13,27 @@ export default function FormNumberInput(_ref) {
 
   var onChangeCustom = function onChangeCustom(event) {
     var value = event.target.value;
-    if (EREG_NUMBER.test(value)) {
+
+    if (value <= rest.min || value >= rest.max) {
+      event.target.value = rest.min;
       onChange(event);
+      event.target.select();
+    } else {
+      if (!isNaN(parseFloat(value)) && isFinite(value)) {
+        onChange(event);
+      } else {
+        if (value === '-') {
+          if (rest.min <= 0) {
+            event.target.value = 0;
+            event.target.select();
+            onChange(event);
+          }
+        } else if (value === '0' || value === '') {
+          event.target.value = rest.min;
+          onChange(event);
+          event.target.select();
+        }
+      }
     }
   };
 
