@@ -108,13 +108,29 @@ export function splitLine(layer, lineID, x, y, catalog) {
 
 
     var splitPointOffset = Geometry.pointPositionOnLineSegment(x0, y0, x1, y1, x, y);
+
     line.holes.forEach(function (holeID) {
       var hole = layer.holes.get(holeID);
-      if (hole.offset < splitPointOffset) {
-        var offset = hole.offset / splitPointOffset;
+
+      var minVertex = Geometry.minVertex({ x: x0, y: y0 }, { x: x1, y: y1 });
+
+      var holeOffset = hole.offset;
+      if (minVertex.x === x1 && minVertex.y === y1) {
+        splitPointOffset = 1 - splitPointOffset;
+        holeOffset = 1 - hole.offset;
+      }
+
+      if (holeOffset < splitPointOffset) {
+        var offset = holeOffset / splitPointOffset;
+        if (minVertex.x === x1 && minVertex.y === y1) {
+          offset = 1 - offset;
+        }
         addHole(layer, hole.type, line0.id, offset, catalog, hole.properties);
       } else {
-        var _offset = (hole.offset - splitPointOffset) / (1 - splitPointOffset);
+        var _offset = (holeOffset - splitPointOffset) / (1 - splitPointOffset);
+        if (minVertex.x === x1 && minVertex.y === y1) {
+          _offset = 1 - _offset;
+        }
         addHole(layer, hole.type, line1.id, _offset, catalog, hole.properties);
       }
     });
@@ -209,24 +225,34 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
       var intersection = Geometry.intersectionFromTwoLineSegment({ x: x0, y: y0 }, { x: x1, y: y1 }, v0, v1);
 
       if (intersection.type === "colinear") {
-        if (!oldHoles) {
-          oldHoles = [];
-        }
+        (function () {
+          if (!oldHoles) {
+            oldHoles = [];
+          }
 
-        layer.lines.get(line.id).holes.forEach(function (holeID) {
-          var hole = layer.holes.get(holeID);
-          var oldLineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
+          var orderedVertices = Geometry.orderVertices([{ x: x0, y: y0 }, { x: x1, y: y1 }]);
 
-          var alpha = Math.atan2(v1.y - v0.y, v1.x - v0.x);
+          layer.lines.get(line.id).holes.forEach(function (holeID) {
+            var hole = layer.holes.get(holeID);
+            var oldLineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
 
-          var xp = oldLineLength * hole.offset * Math.cos(alpha) + v0.x;
-          var yp = oldLineLength * hole.offset * Math.sin(alpha) + v0.y;
+            var alpha = Math.atan2(orderedVertices[1].y - orderedVertices[0].y, orderedVertices[1].x - orderedVertices[0].x);
 
-          oldHoles.push({ hole: hole, offsetPosition: { x: xp, y: yp } });
-        });
+            var offset = hole.offset;
 
-        removeLine(layer, line.id);
-        points.push(v0, v1);
+            if (orderedVertices[1].x === line.vertices.get(1).x && orderedVertices[1].y === line.vertices(1).y) {
+              offset = 1 - offset;
+            }
+
+            var xp = oldLineLength * offset * Math.cos(alpha) + v0.x;
+            var yp = oldLineLength * offset * Math.sin(alpha) + v0.y;
+
+            oldHoles.push({ hole: hole, offsetPosition: { x: xp, y: yp } });
+          });
+
+          removeLine(layer, line.id);
+          points.push(v0, v1);
+        })();
       }
 
       if (intersection.type === "intersecting" && !hasCommonEndpoint) {
