@@ -1,4 +1,4 @@
-import {SELECT_LAYER, ADD_LAYER, SET_LAYER_PROPERTIES} from '../constants';
+import {SELECT_LAYER, ADD_LAYER, SET_LAYER_PROPERTIES, OPEN_LAYER_CONFIGURATOR, REMOVE_LAYER} from '../constants';
 
 export function selectLayer(layerID) {
   return {
@@ -7,6 +7,13 @@ export function selectLayer(layerID) {
   }
 }
 
+export function openLayerConfigurator(layerID){
+  return {
+    type: OPEN_LAYER_CONFIGURATOR,
+    layerID
+  }
+}
+
 export function addLayer(name, altitude) {
   return {
     type: ADD_LAYER,
@@ -21,3 +28,10 @@ export function setLayerProperties(layerID, properties) {
     properties
   }
 }
+
+export function removeLayer(layerID) {
+  return {
+    type: REMOVE_LAYER,
+    layerID,
+  }
+}
