@@ -30,5 +30,6 @@ export default {
   "Configure layer": "Configure layer",
   "Properties: [{0}] {1}": "Properties: [{0}] {1}",
   "Get Screenshot" : "Get Screenshot",
-  "Catalog" : "Catalog"
+  "Catalog" : "Catalog",
+  "Rotation" : "Rotation"
 }
